import type { BasisTheoryElements, CardElement, CardExpirationDateElement, CardNumberElement, CardVerificationCodeElement, CreateCardElementOptions, CreateCardExpirationDateElementOptions, CreateCardNumberElementOptions, CreateCardVerificationCodeElementOptions, CreateTextElementOptions, TextElement, TokenizeData as ElementsTokenizeData, Tokens as ElementsTokens, TokenIntents as ElementsTokenIntents } from './types/elements';
import type { TokenizeData } from './types/models';
import type { ApplicationKeys, Applications, ApplicationTemplates, BasisTheory as IBasisTheory, BasisTheoryInit, BasisTheoryInitOptions, BasisTheoryInitOptionsWithElements, BasisTheoryInitOptionsWithoutElements, HttpClient, Logs, Permissions, Proxies, Proxy, ReactorFormulas, Reactors, RequestOptions, Sessions, Tenants, ThreeDS, TokenIntents, Tokens } from './types/sdk';
export declare class BasisTheory implements BasisTheoryInit, IBasisTheory, BasisTheoryElements {
    private _initStatus;
    private _applicationKeys?;
    private _applications?;
    private _applicationTemplates?;
    private _elements?;
    private _initOptions?;
    private _logs?;
    private _permissions?;
    private _proxies?;
    private _proxy?;
    private _reactorFormulas?;
    private _reactors?;
    private _sessions?;
    private _tenants?;
    private _threeds?;
    private _tokenize?;
    private _tokens?;
    private _tokenIntents?;
    init(apiKey: string | undefined, options?: BasisTheoryInitOptionsWithoutElements): Promise<IBasisTheory>;
    init(apiKey: string | undefined, options: BasisTheoryInitOptionsWithElements): Promise<IBasisTheory & BasisTheoryElements>;
    createElement(type: 'card', options?: CreateCardElementOptions): CardElement;
    createElement(type: 'text', options: CreateTextElementOptions): TextElement;
    createElement(type: 'cardNumber', options: CreateCardNumberElementOptions): CardNumberElement;
    createElement(type: 'cardExpirationDate', options: CreateCardExpirationDateElementOptions): CardExpirationDateElement;
    createElement(type: 'cardVerificationCode', options: CreateCardVerificationCodeElementOptions): CardVerificationCodeElement;
    tokenize(tokens: TokenizeData & ElementsTokenizeData, options?: RequestOptions): Promise<TokenizeData>;
    private loadElements;
    get initOptions(): Required<BasisTheoryInitOptions>;
    get tokens(): Tokens & ElementsTokens;
    get applications(): Applications;
    get applicationKeys(): ApplicationKeys;
    get applicationTemplates(): ApplicationTemplates;
    get client(): HttpClient | undefined;
    get tenants(): Tenants;
    get logs(): Logs;
    /**
     * @deprecated Reactor Formulas are now deprecated and will be removed in a future release.
     * @description We have introduced a `code` property for Reactors to replace Formula's code. For more details visit [our API reference](https://developers.basistheory.com/docs/api/reactors#create-reactor).
     */
    get reactorFormulas(): ReactorFormulas;
    get reactors(): Reactors;
    get permissions(): Permissions;
    get proxies(): Proxies;
    get proxy(): Proxy;
    get sessions(): Sessions;
    get threeds(): ThreeDS;
    get tokenIntents(): TokenIntents & ElementsTokenIntents;
    /**
     * @deprecated
     */
    get elements(): BasisTheoryElements;
    set elements(elements: BasisTheoryElements);
}
