import type { BinDetails } from './bin-details';
import { CardDetails } from './card-details';
import type { Primitive, TokenBase } from './shared';
declare const DATA_CLASSIFICATIONS: readonly ["general", "bank", "pci", "pii"];
type DataClassification = typeof DATA_CLASSIFICATIONS[number];
declare const DATA_IMPACT_LEVELS: readonly ["low", "moderate", "high"];
type DataImpactLevel = typeof DATA_IMPACT_LEVELS[number];
declare const DATA_RESTRICTION_POLICIES: readonly ["mask", "redact"];
type DataRestrictionPolicy = typeof DATA_RESTRICTION_POLICIES[number];
type MaskObject = {
    [member: string]: TokenMask;
};
type MaskArray = Array<TokenMask>;
type TokenMask = string | null | MaskObject | MaskArray;
interface TokenEncryptionKey {
    key: string;
    alg: string;
}
interface TokenEncryption {
    cek: TokenEncryptionKey;
    kek: TokenEncryptionKey;
}
interface TokenPrivacy {
    classification?: DataClassification;
    impactLevel?: DataImpactLevel;
    restrictionPolicy?: DataRestrictionPolicy;
}
interface TokenEnrichments {
    binDetails?: BinDetails;
    cardDetails?: CardDetails;
}
type Token<DataType = Primitive> = TokenBase<DataType> & {
    id: string;
    privacy?: TokenPrivacy;
    containers?: string[];
    encryption?: TokenEncryption;
    searchIndexes?: string[];
    fingerprintExpression?: string;
    mask?: TokenMask;
    expiresAt?: string;
    enrichments?: TokenEnrichments;
    tenantId: string;
    fingerprint?: string;
    metadata?: Record<string, string>;
    _debug?: Record<string, unknown>;
};
type CreateToken<DataType = Primitive> = Pick<Token<DataType>, 'type' | 'data' | 'privacy' | 'containers' | 'metadata' | 'encryption' | 'searchIndexes' | 'fingerprintExpression' | 'mask' | 'expiresAt'> & {
    deduplicateToken?: boolean;
    id?: string;
    _debug?: Record<string, unknown>;
};
type UpdateToken<DataType = Primitive> = Partial<Pick<Token<DataType>, 'data' | 'containers' | 'metadata' | 'encryption' | 'searchIndexes' | 'fingerprintExpression' | 'mask' | 'expiresAt'> & {
    privacy: Omit<TokenPrivacy, 'classification'>;
    deduplicateToken: boolean;
    _debug?: Record<string, unknown>;
}>;
export type { Token, TokenEnrichments, CreateToken, UpdateToken, DataClassification, DataImpactLevel, DataRestrictionPolicy, };
export { DATA_CLASSIFICATIONS, DATA_IMPACT_LEVELS, DATA_RESTRICTION_POLICIES };
